<img width="300px" src="https://sickrage.ca/img/logo-stacked.png" />

# 

##Thu Dec 24 2020 15:52:52 GMT+0000 (Coordinated Universal Time)


## Bug Fixes
  - Fixed issue with configuration migration Added code to perform requirements check and install any missing requirements on startup of app
  ([5780cfa0](https://gitlab-ci-token:dLp7ErGSkP-JBz-sy79V@git.sickrage.ca/SiCKRAGE/sickrage/commit/5780cfa0b59bfd7269e6b01b55817ec709818a24))




